redvox.tests.common.test_event_stream API documentation

# Module `redvox.tests.common.test_event_stream`

Expand source code

    import unittest

    import redvox.tests as tests
    import redvox.common.event_stream as es

    class EventTest(unittest.TestCase):
        @classmethod
        def setUpClass(cls) -> None:
            cls.input_dir = tests.TEST_DATA_DIR
            cls.event = es.Event(0, "testevent")
            cls.real = es.Event(0, "testreal")

        def test_get_values(self):
            self.assertEqual(self.event.get_string_values(), {})
            self.assertEqual(self.event.get_numeric_values(), {})
            self.assertEqual(self.event.get_boolean_values(), {})
            self.assertEqual(self.event.get_byte_values(), {})

        def test_get_columns(self):
            self.assertEqual(len(self.event.get_string_column("fail")), 0)

        def test_get_classification(self):
            self.assertEqual(len(self.event.get_classification(0)), 0)

        def test_get_string_item(self):
            self.assertEqual(self.event.get_string_item("fail"), None)

        def test_get_numeric_item(self):
            self.assertEqual(self.event.get_numeric_item("fail"), None)

        def test_get_boolean_item(self):
            self.assertEqual(self.event.get_boolean_item("fail"), None)

        def test_get_byte_item(self):
            self.assertEqual(self.event.get_byte_item("fail"), None)

        def test_get_timestamps(self):
            self.assertEqual(self.event.get_timestamp(), 0)
            self.assertEqual(self.event.get_uncorrected_timestamp(), 0)

    class EventStreamTest(unittest.TestCase):
        @classmethod
        def setUpClass(cls) -> None:
            cls.input_dir = tests.TEST_DATA_DIR
            cls.eventstream = es.EventStream("testevent")

        def test_get_event(self):
            self.assertEqual(self.eventstream.get_event(), None)
            self.assertEqual(self.eventstream.get_event(0), None)
            self.assertEqual(self.eventstream.get_event(-1), None)

## Classes

`class EventStreamTest (methodName='runTest')`

  A class whose instances are single test cases.

  By default, the test code itself should be placed in a method named 'runTest'.

  If the fixture may be used for many test cases, create as many test methods as are needed. When instantiating such a TestCase subclass, specify in the constructor arguments the name of the test method that the instance is to execute.

  Test authors should subclass TestCase for their own tests. Construction and deconstruction of the test's environment ('fixture') can be implemented by overriding the 'setUp' and 'tearDown' methods respectively.

  If it is necessary to override the init method, the base class init method must always be called. It is important that subclasses should not change the signature of their init method, since instances of the classes are instantiated automatically by parts of the framework in order to be run.

  When subclassing TestCase, you can set these attributes: * failureException: determines which exception will be raised when the instance's assertion methods fail; test methods raising this exception will be deemed to have 'failed' rather than 'errored'. * longMessage: determines whether long messages (including repr of objects used in assert methods) will be printed on failure in addition to any explicit message passed. * maxDiff: sets the maximum length of a diff in failure messages by assert methods using difflib. It is looked up as an instance attribute so can be configured by individual tests if required.

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  Expand source code

      class EventStreamTest(unittest.TestCase):
          @classmethod
          def setUpClass(cls) -> None:
              cls.input_dir = tests.TEST_DATA_DIR
              cls.eventstream = es.EventStream("testevent")

          def test_get_event(self):
              self.assertEqual(self.eventstream.get_event(), None)
              self.assertEqual(self.eventstream.get_event(0), None)
              self.assertEqual(self.eventstream.get_event(-1), None)

  ### Ancestors

  - unittest.case.TestCase

  ### Static methods

  `def setUpClass() ‑> None`

    Hook method for setting up class fixture before running tests in the class.

    Expand source code

        @classmethod
        def setUpClass(cls) -> None:
            cls.input_dir = tests.TEST_DATA_DIR
            cls.eventstream = es.EventStream("testevent")

  ### Methods

  `def test_get_event(self)`
    Expand source code

        def test_get_event(self):
            self.assertEqual(self.eventstream.get_event(), None)
            self.assertEqual(self.eventstream.get_event(0), None)
            self.assertEqual(self.eventstream.get_event(-1), None)

`class EventTest (methodName='runTest')`

  A class whose instances are single test cases.

  By default, the test code itself should be placed in a method named 'runTest'.

  If the fixture may be used for many test cases, create as many test methods as are needed. When instantiating such a TestCase subclass, specify in the constructor arguments the name of the test method that the instance is to execute.

  Test authors should subclass TestCase for their own tests. Construction and deconstruction of the test's environment ('fixture') can be implemented by overriding the 'setUp' and 'tearDown' methods respectively.

  If it is necessary to override the init method, the base class init method must always be called. It is important that subclasses should not change the signature of their init method, since instances of the classes are instantiated automatically by parts of the framework in order to be run.

  When subclassing TestCase, you can set these attributes: * failureException: determines which exception will be raised when the instance's assertion methods fail; test methods raising this exception will be deemed to have 'failed' rather than 'errored'. * longMessage: determines whether long messages (including repr of objects used in assert methods) will be printed on failure in addition to any explicit message passed. * maxDiff: sets the maximum length of a diff in failure messages by assert methods using difflib. It is looked up as an instance attribute so can be configured by individual tests if required.

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  Expand source code

      class EventTest(unittest.TestCase):
          @classmethod
          def setUpClass(cls) -> None:
              cls.input_dir = tests.TEST_DATA_DIR
              cls.event = es.Event(0, "testevent")
              cls.real = es.Event(0, "testreal")

          def test_get_values(self):
              self.assertEqual(self.event.get_string_values(), {})
              self.assertEqual(self.event.get_numeric_values(), {})
              self.assertEqual(self.event.get_boolean_values(), {})
              self.assertEqual(self.event.get_byte_values(), {})

          def test_get_columns(self):
              self.assertEqual(len(self.event.get_string_column("fail")), 0)

          def test_get_classification(self):
              self.assertEqual(len(self.event.get_classification(0)), 0)

          def test_get_string_item(self):
              self.assertEqual(self.event.get_string_item("fail"), None)

          def test_get_numeric_item(self):
              self.assertEqual(self.event.get_numeric_item("fail"), None)

          def test_get_boolean_item(self):
              self.assertEqual(self.event.get_boolean_item("fail"), None)

          def test_get_byte_item(self):
              self.assertEqual(self.event.get_byte_item("fail"), None)

          def test_get_timestamps(self):
              self.assertEqual(self.event.get_timestamp(), 0)
              self.assertEqual(self.event.get_uncorrected_timestamp(), 0)

  ### Ancestors

  - unittest.case.TestCase

  ### Static methods

  `def setUpClass() ‑> None`

    Hook method for setting up class fixture before running tests in the class.

    Expand source code

        @classmethod
        def setUpClass(cls) -> None:
            cls.input_dir = tests.TEST_DATA_DIR
            cls.event = es.Event(0, "testevent")
            cls.real = es.Event(0, "testreal")

  ### Methods

  `def test_get_boolean_item(self)`
    Expand source code

        def test_get_boolean_item(self):
            self.assertEqual(self.event.get_boolean_item("fail"), None)

  `def test_get_byte_item(self)`
    Expand source code

        def test_get_byte_item(self):
            self.assertEqual(self.event.get_byte_item("fail"), None)

  `def test_get_classification(self)`
    Expand source code

        def test_get_classification(self):
            self.assertEqual(len(self.event.get_classification(0)), 0)

  `def test_get_columns(self)`
    Expand source code

        def test_get_columns(self):
            self.assertEqual(len(self.event.get_string_column("fail")), 0)

  `def test_get_numeric_item(self)`
    Expand source code

        def test_get_numeric_item(self):
            self.assertEqual(self.event.get_numeric_item("fail"), None)

  `def test_get_string_item(self)`
    Expand source code

        def test_get_string_item(self):
            self.assertEqual(self.event.get_string_item("fail"), None)

  `def test_get_timestamps(self)`
    Expand source code

        def test_get_timestamps(self):
            self.assertEqual(self.event.get_timestamp(), 0)
            self.assertEqual(self.event.get_uncorrected_timestamp(), 0)

  `def test_get_values(self)`
    Expand source code

        def test_get_values(self):
            self.assertEqual(self.event.get_string_values(), {})
            self.assertEqual(self.event.get_numeric_values(), {})
            self.assertEqual(self.event.get_boolean_values(), {})
            self.assertEqual(self.event.get_byte_values(), {})